# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-11-01 08:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("spectator_core", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="creator",
            name="slug",
            field=models.SlugField(null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-11-01 16:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("spectator_events", "0002_event_slug"),
    ]

    operations = [
        migrations.AddField(
            model_name="classicalwork",
            name="slug",
            field=models.SlugField(blank=True, default="a", max_length=10),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="dancepiece",
            name="slug",
            field=models.SlugField(blank=True, default="a", max_length=10),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="movie",
            name="slug",
            field=models.SlugField(blank=True, default="a", max_length=10),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="play",
            name="slug",
            field=models.SlugField(blank=True, default="a", max_length=10),
            preserve_default=False,
        ),
    ]
